@@ -30,20 +30,20 @@ namespace K3b {
 
     public:
         explicit AudioTrackReader( AudioTrack& track, QObject* parent = 0 );
-        ~AudioTrackReader();
+        ~AudioTrackReader() override;
 
         const AudioTrack& track() const;
         AudioTrack& track();
 
-        virtual bool open( OpenMode mode = QIODevice::ReadOnly );
-        virtual void close();
-        virtual bool isSequential() const;
-        virtual qint64 size() const;
-        virtual bool seek( qint64 pos );
+        bool open( OpenMode mode = QIODevice::ReadOnly ) override;
+        void close() override;
+        bool isSequential() const override;
+        qint64 size() const override;
+        bool seek( qint64 pos ) override;
 
     protected:
-        virtual qint64 writeData( const char* data, qint64 len );
-        virtual qint64 readData( char* data, qint64 maxlen );
+        qint64 writeData( const char* data, qint64 len ) override;
+        qint64 readData( char* data, qint64 maxlen ) override;
 
     private Q_SLOTS:
         void slotTrackChanged();
